# GW_follow-upper
Determines the area, and probability of follow up campaigns for GW triggers
![alt text](https://github.com/ryanc123/GW_follow-upper/blob/master/Tests/sky_cover.png)


Example of script output using S190814bv and a random GOTO image 


~~~
Version 0.1 - 14/10/2019
Ry Cutter
